@@ -1,25 +1,34 @@
-import PythonQt
+import PyQt4
 
 class example_plugin(): # class name and filename must match!
 
-    def SinkName(self):
+    def __init__():
+        self.ready = False
+
+    def getName(self):
         return "python_test_sink" # this is not displayed, might be used in the future internally
 
-    def SinkText(self):
+    def getText(self):
         return "Python Test Sink" # this is displayed on the button
 
-    def SinkImage(self):
+    def getImage(self):
         # return an image to be displayed on the button
-        pass
+        return Nothing
 
-    def HandleBarcode(self, barcodeType, barcodeData):
+    def getInformativeText(self):
+        return "Informative text"
+
+    def clickAction(self):
         # this is the callback that indicates the button has been pressed
         # do whatever processing on the barcode data
         # add more detail here, e.g. opening a window to display stuff to the user
-        pass
+        print "This is from Python!!"
 
-    def CheckBarcode(self, barcodeType, barcodeData):
+    def barcodeAnalysed(self, barcodeType, barcodeData):
         # see if we want to handle this particular barcode
         # return true or false depending on whether we like the content
-        return True
+        self.ready = True
+
+def mbarcode_plugin_instance():
+    return example_plugin()
 
