@@ -17,6 +17,7 @@ class PythonQTWrapperPlugin : public QObject, public PluginInterface
     Q_INTERFACES(PluginInterface)
 public:
     //PythonQTWrapperPlugin();
+    ~PythonQTWrapperPlugin();
     void initInterface(QWidget *parent);
     QSet<PluginAction*> getPluginActions();
     bool hasSettingsWindow() {return false;};
@@ -25,6 +26,7 @@ public:
 
 private:
     MaemoBarcodeWindow *parent;
+    bool initialised;
 
     // this is a list of the sinks provided by all the ini files
     QList<PythonQTWrapperSink *> sinks;
