@@ -12,9 +12,11 @@ PythonQTWrapperSink::PythonQTWrapperSink(const PluginInterface *interface, PyObj
     this->sinkInstance=sinkInstance;
 }
 
-QString PythonQTWrapperSink::getName()
+QString PythonQTWrapperSink::getName() // this does not change, so we save the name and can then return it with less overhead
 {
-    QString myname("");
+    if(pluginName.length()>0)
+        return pluginName;
+
     // get class method
     //qDebug() << "PythonQTWrapperSink just called getName()";
 
@@ -23,8 +25,8 @@ QString PythonQTWrapperSink::getName()
     if (output != NULL){
         char *str = PyString_AsString(output);
         if(str){
-            myname.append(str);
-            qDebug() << "PythonQTWrapperSink::getName() returning " << myname;
+            pluginName.append(str);
+            //qDebug() << "PythonQTWrapperSink::getName() returning " << myname;
         }else
             if ( PyErr_Occurred() )
                 PyErr_Print();
@@ -33,7 +35,7 @@ QString PythonQTWrapperSink::getName()
             PyErr_Print();
     }
     Py_DECREF(output);
-    return myname;
+    return pluginName;
 };
 
 QString PythonQTWrapperSink::getText()
@@ -49,7 +51,7 @@ QString PythonQTWrapperSink::getText()
         char *str = PyString_AsString(output);
         if(str){
             mytext.append(str);
-            qDebug() << "PythonQTWrapperSink::getText() returning " << mytext;
+            //qDebug() << "PythonQTWrapperSink::getText() returning " << mytext;
         }else
             if ( PyErr_Occurred() )
                 PyErr_Print();
@@ -86,7 +88,7 @@ QString PythonQTWrapperSink::getInformativeText() {
         char *str = PyString_AsString(output);
         if(str){
             mytext.append(str);
-            qDebug() << "PythonQTWrapperSink::getInformativeText() returning " << mytext;
+            //qDebug() << "PythonQTWrapperSink::getInformativeText() returning " << mytext;
         }else
             if ( PyErr_Occurred() )
                 PyErr_Print();
@@ -110,7 +112,7 @@ bool PythonQTWrapperSink::isReady()
 
     if (output != NULL){
         ready = (bool)PyInt_AsLong(output); // output will be -1 if an error occurred, but that works for us
-        qDebug() << "PythonQTWrapperSink::isReady() returning " << ready;
+        //qDebug() << "PythonQTWrapperSink::isReady() returning " << ready;
         if ( PyErr_Occurred() )
             PyErr_Print();
     }else{
